# Import functions from File_Man
from .osManag import (
    touch,
    cat,
    nano,
    rm,
    mkdir,
    rmdir,
    ren,
    mv,
    cd,
    tree,
    pwd,
    ls,
    ls_l,
    istime,
    size,
    get_info,
    get_path
)

__all__ = [
    "touch",
    "cat",
    "nano",
    "rm",
    "mkdir",
    "rmdir",
    "ren",
    "mv",
    "cd",
    "tree",
    "pwd",
    "ls",
    "ls_l",
    "istime",
    "size",
    "get_info",
    "get_path"
]
